@@ -212,8 +212,8 @@ class action_plugin_fckg_edit extends DokuWiki_Action_Plugin {
              );
 // $temp=array();
 // trigger_event('HTML_EDITFORM_INJECTION', $temp);
-// print_r($_POST);
-
+// print_r($_REQUEST);
+  
 ?>
 
    <form id="dw__editform" method="post" action="<?php echo script()?>" accept-charset="<?php echo $lang['encoding']?>"><div class="no">
@@ -282,43 +282,65 @@ else {
           }
   }  
 }
-  
+
+$BIG_FILE_disabled="";
+if($this->big_file()) {
+  $BIG_FILE_disabled='disabled';
+}
 ?>
+<input class="button" type="submit" name="do[draftdel]" value="<?php echo $lang['btn_cancel']?>" tabindex="8" />
+<!-- table width="100%" border=0><tr><td  -->
             <input class="button" id="edbtn__preview" type="submit" name="do[preview]"  
                      <?php echo $DW_EDIT_disabled; ?>
                      onmousedown="saveFCKEditorNode(this);return true;"  
-                   
+                     <?php echo $BIG_FILE_disabled; ?>
                      value="FCK Preview" accesskey="p" title="<?php echo $lang['btn_preview']?> 
                      [ALT+P]" tabindex="7" />
-            <input class="button" type="submit" name="do[draftdel]" value="<?php echo $lang['btn_cancel']?>" tabindex="8" />
-            <input class="button" type="button" value = "Refresh"
-                   title="Reset lock"  
+
+  
+            <input class="button" type="button" value = "Language"
+                   title="Select language for spell checker"  
+                   onclick="aspell_window();"  
+                  /> 
+
+            <br />
+             <input class="button" type="button" value = "Refresh"
+                   title="Reset lock timer"  
                    onclick="renewLock();"  
-                  />          
-            <br><input class="button"   <?php echo $DW_EDIT_disabled; ?>
+                  />&nbsp;&nbsp;&nbsp;
+ 
+                <input class="button"   <?php echo $DW_EDIT_disabled; ?>
                  onclick ="setDWEditCookie(2, this);this.form.submit();" 
-                 type="submit" name="do[edit]" value="DW Edit" accesskey="p" title="<?php echo $lang['btn_edit']?> [ALT+E]" tabindex="6" />
-            &nbsp;&nbsp;<input type="checkbox" id="fck_convert" name="fck_convert" value="fck_convert"
+                 type="submit" name="do[edit]" value="DW Edit" accesskey="p" 
+                 title="Switch from FCK Editor to Native DokuWiki Editor"
+                 tabindex="6" />
+            &nbsp;<input type="checkbox" id="fck_convert" name="fck_convert" value="fck_convert"
                               <?php echo $DW_EDIT_disabled; ?>
                              CHECKED  
                              onchange="document.getElementById('fckg_bak').checked=false;"
                              onmouseup="document.getElementById('fckg_bak').checked=false;"
-                             />  Convert FCK to native DokuWiki Syntax
+                             title="Conversion will not be perfect"
+                             />  Convert FCK to DokuWiki Syntax
             &nbsp;&nbsp;<input type="checkbox" name="fckg_bak" value="fckg_bak" id="fckg_bak"
                               <?php echo $DW_EDIT_disabled; ?>
                               onchange="document.getElementById('fck_convert').checked=false;"
                               onmouseup="document.getElementById('fck_convert').checked=false;"
-                             /> Discard  FCK and open blank editor<br />
+                              title="Your work will be lost"
+                             /> Discard  FCK and open blank editor&nbsp;&nbsp;&nbsp;&nbsp;
 
-            <input type="checkbox" name="fckg_timer" value="fckg_timer"  id = "fckg_timer"
-                      style = 'display:none;'
+ <br/ ><!--  td-->
+<input type="checkbox" name="fckg_timer" value="fckg_timer"  id = "fckg_timer"
+                      style = display:none;'
                       onclick="disableDokuWikiLockTimer();";  <?php echo $disabled  ?>
                 / > <span id='fckg_timer_label'
                     style = 'display:none;'>Disable editor time-out messsages </span> 
-
-               
+<!--/table -->
+       
 
   <script language="javascript">
+        function aspell_window() {
+          window.open("lib/plugins/fckg/fckeditor/aspell.php","smallwin", "width=600,height=500,scrollbars=yes");
+        }
         unsetDokuWikiLockTimer();  
 
        /**
@@ -452,6 +474,20 @@ else {
   }
 
 
+ function big_file() {
+   $big_files = $this->getConf('big_files');
+   if (!$big_files) return false;
+  
+  $ns = str_replace(':','/', $_REQUEST['id']);
+  $path = DOKU_INC . 'data/pages/' . $ns . '.txt';
+  if(!file_exists($path)) return false;
+  
+  $fsz = filesize($path);  
+  $big_sz = $this->getConf('big_file_sz'); 
+ // echo "$path, $fsz, $big_sz";
+  if($fsz >= $big_sz) return true;
+  return false;   
+ }
 
 
 
